summaryrefslogtreecommitdiff
path: root/TAO/TAO_IDL/ast/ast_type.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/TAO_IDL/ast/ast_type.cpp')
-rw-r--r--TAO/TAO_IDL/ast/ast_type.cpp28
1 files changed, 15 insertions, 13 deletions
diff --git a/TAO/TAO_IDL/ast/ast_type.cpp b/TAO/TAO_IDL/ast/ast_type.cpp
index ffbdb1f81ed..06115de836d 100644
--- a/TAO/TAO_IDL/ast/ast_type.cpp
+++ b/TAO/TAO_IDL/ast/ast_type.cpp
@@ -157,14 +157,14 @@ AST_Type::compute_size_type (void)
return 0;
}
-bool
+idl_bool
AST_Type::in_recursion (ACE_Unbounded_Queue<AST_Type *> &)
{
// By default we are not involved in recursion.
return 0;
}
-bool
+idl_bool
AST_Type::is_defined (void)
{
// AST_Interface, AST_Structure, and AST_Union will
@@ -172,41 +172,41 @@ AST_Type::is_defined (void)
return 1;
}
-bool
+idl_bool
AST_Type::ifr_added (void)
{
return this->ifr_added_;
}
void
-AST_Type::ifr_added (bool val)
+AST_Type::ifr_added (idl_bool val)
{
this->ifr_added_ = val;
}
-bool
+idl_bool
AST_Type::ifr_fwd_added (void)
{
return this->ifr_fwd_added_;
}
void
-AST_Type::ifr_fwd_added (bool val)
+AST_Type::ifr_fwd_added (idl_bool val)
{
this->ifr_fwd_added_ = val;
}
-bool
+idl_bool
AST_Type::has_constructor (void)
{
return this->has_constructor_;
}
void
-AST_Type::has_constructor (bool value)
+AST_Type::has_constructor (idl_bool value)
{
// Similarly to be_decl::size_type_, once this
// gets set to true, we don't want it to
// change back.
if (this->has_constructor_ == 0)
{
@@ -345,7 +345,9 @@ AST_Type::nested_name (const char* local_name,
use_next = ACE_OS::strstr (use_curr, "::");
// If the scopes are identical, don't supply them.
- if (ACE_OS::strcmp (def_name, use_name) == 0)
+ if (ACE_OS::strcmp (def_name,
+ use_name)
+ == 0)
{
if (prefix != 0)
{
@@ -531,7 +533,7 @@ AST_Type::nested_name (const char* local_name,
return this->nested_type_name_;
}
-bool
+idl_bool
AST_Type::match_names (AST_Type *t, ACE_Unbounded_Queue<AST_Type *> &list)
{
for (ACE_Unbounded_Queue_Iterator<AST_Type *> iter (list);
@@ -546,11 +548,11 @@ AST_Type::match_names (AST_Type *t, ACE_Unbounded_Queue<AST_Type *> &list)
if (!ACE_OS::strcmp (t->full_name (),
(*temp)->full_name ()))
{
- return true;
+ return I_TRUE;
}
}
- return false;
+ return I_FALSE;
}
int
@@ -172,41 +172,41 @@ AST_Type::is_defined (void)
{
// Similarly to be_decl::size_type_, once this
- // gets set to true, we don't want it to
+ // gets set to I_TRUE, we don't want it to
// change back.
if (this->has_constructor_ == 0)